@@ -40,6 +40,7 @@ from .type_defs import (
     ListProtectionsResponseTypeDef,
     ListResourcesInProtectionGroupResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    ResponseActionTypeDef,
     TagTypeDef,
     TimeRangeTypeDef,
 )
@@ -80,7 +81,7 @@ class Exceptions:
 
 class ShieldClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html)
     """
 
@@ -98,7 +99,7 @@ class ShieldClient(BaseClient):
         bucket containing log data such as Application Load Balancer access logs,
         CloudFront logs, or logs from third party sources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.associate_drt_log_bucket)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.associate_drt_log_bucket)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_drt_log_bucket)
         """
 
@@ -108,7 +109,7 @@ class ShieldClient(BaseClient):
         your Amazon Web Services account to assist with DDoS attack mitigation during
         potential attacks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.associate_drt_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.associate_drt_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_drt_role)
         """
 
@@ -116,7 +117,7 @@ class ShieldClient(BaseClient):
         """
         Adds health-based detection to the Shield Advanced protection for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.associate_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.associate_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_health_check)
         """
 
@@ -127,7 +128,7 @@ class ShieldClient(BaseClient):
         Initializes proactive engagement and sets the list of contacts for the Shield
         Response Team (SRT) to use.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.associate_proactive_engagement_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.associate_proactive_engagement_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_proactive_engagement_details)
         """
 
@@ -135,7 +136,7 @@ class ShieldClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#can_paginate)
         """
 
@@ -145,7 +146,7 @@ class ShieldClient(BaseClient):
         """
         Enables Shield Advanced for a specific Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.create_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.create_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_protection)
         """
 
@@ -163,7 +164,7 @@ class ShieldClient(BaseClient):
         Creates a grouping of protected resources so they can be handled as a
         collective.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.create_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.create_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_protection_group)
         """
 
@@ -171,7 +172,7 @@ class ShieldClient(BaseClient):
         """
         Activates Shield Advanced for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.create_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.create_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_subscription)
         """
 
@@ -179,7 +180,7 @@ class ShieldClient(BaseClient):
         """
         Deletes an Shield Advanced  Protection .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.delete_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.delete_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_protection)
         """
 
@@ -187,7 +188,7 @@ class ShieldClient(BaseClient):
         """
         Removes the specified protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.delete_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.delete_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_protection_group)
         """
 
@@ -195,7 +196,7 @@ class ShieldClient(BaseClient):
         """
         Removes Shield Advanced from an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.delete_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.delete_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_subscription)
         """
 
@@ -203,7 +204,7 @@ class ShieldClient(BaseClient):
         """
         Describes the details of a DDoS attack.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.describe_attack)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.describe_attack)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_attack)
         """
 
@@ -213,7 +214,7 @@ class ShieldClient(BaseClient):
         the last year for all resources that belong to your account, regardless of
         whether you've defined Shield protections for them.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.describe_attack_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.describe_attack_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_attack_statistics)
         """
 
@@ -223,7 +224,7 @@ class ShieldClient(BaseClient):
         Response Team (SRT) to access your Amazon Web Services account while assisting
         with attack mitigation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.describe_drt_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.describe_drt_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_drt_access)
         """
 
@@ -235,7 +236,7 @@ class ShieldClient(BaseClient):
         can use to contact you if you have proactive engagement enabled, for escalations
         to the SRT and to initiate proactive customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.describe_emergency_contact_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.describe_emergency_contact_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_emergency_contact_settings)
         """
 
@@ -245,7 +246,7 @@ class ShieldClient(BaseClient):
         """
         Lists the details of a  Protection object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.describe_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.describe_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_protection)
         """
 
@@ -255,7 +256,7 @@ class ShieldClient(BaseClient):
         """
         Returns the specification for the specified protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.describe_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.describe_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_protection_group)
         """
 
@@ -263,16 +264,25 @@ class ShieldClient(BaseClient):
         """
         Provides details about the Shield Advanced subscription for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.describe_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.describe_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_subscription)
         """
 
+    def disable_application_layer_automatic_response(self, *, ResourceArn: str) -> Dict[str, Any]:
+        """
+        Disable the Shield Advanced automatic application layer DDoS mitigation feature
+        for the resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.disable_application_layer_automatic_response)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disable_application_layer_automatic_response)
+        """
+
     def disable_proactive_engagement(self) -> Dict[str, Any]:
         """
         Removes authorization from the Shield Response Team (SRT) to notify contacts
         about escalations to the SRT and to initiate proactive customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.disable_proactive_engagement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.disable_proactive_engagement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disable_proactive_engagement)
         """
 
@@ -281,7 +291,7 @@ class ShieldClient(BaseClient):
         Removes the Shield Response Team's (SRT) access to the specified Amazon S3
         bucket containing the logs that you shared previously.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.disassociate_drt_log_bucket)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.disassociate_drt_log_bucket)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_drt_log_bucket)
         """
 
@@ -290,7 +300,7 @@ class ShieldClient(BaseClient):
         Removes the Shield Response Team's (SRT) access to your Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.disassociate_drt_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.disassociate_drt_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_drt_role)
         """
 
@@ -301,17 +311,28 @@ class ShieldClient(BaseClient):
         Removes health-based detection from the Shield Advanced protection for a
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.disassociate_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.disassociate_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_health_check)
         """
 
+    def enable_application_layer_automatic_response(
+        self, *, ResourceArn: str, Action: "ResponseActionTypeDef"
+    ) -> Dict[str, Any]:
+        """
+        Enable the Shield Advanced automatic application layer DDoS mitigation for the
+        resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.enable_application_layer_automatic_response)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#enable_application_layer_automatic_response)
+        """
+
     def enable_proactive_engagement(self) -> Dict[str, Any]:
         """
         Authorizes the Shield Response Team (SRT) to use email and phone to notify
         contacts about escalations to the SRT and to initiate proactive customer
         support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.enable_proactive_engagement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.enable_proactive_engagement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#enable_proactive_engagement)
         """
 
@@ -325,7 +346,7 @@ class ShieldClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#generate_presigned_url)
         """
 
@@ -333,7 +354,7 @@ class ShieldClient(BaseClient):
         """
         Returns the `SubscriptionState` , either `Active` or `Inactive` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.get_subscription_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.get_subscription_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#get_subscription_state)
         """
 
@@ -350,7 +371,7 @@ class ShieldClient(BaseClient):
         Returns all ongoing DDoS attacks or all DDoS attacks during a specified time
         period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.list_attacks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.list_attacks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_attacks)
         """
 
@@ -360,7 +381,7 @@ class ShieldClient(BaseClient):
         """
         Retrieves the  ProtectionGroup objects for the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.list_protection_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.list_protection_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_protection_groups)
         """
 
@@ -370,7 +391,7 @@ class ShieldClient(BaseClient):
         """
         Lists all  Protection objects for the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.list_protections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.list_protections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_protections)
         """
 
@@ -380,7 +401,7 @@ class ShieldClient(BaseClient):
         """
         Retrieves the resources that are included in the protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.list_resources_in_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.list_resources_in_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_resources_in_protection_group)
         """
 
@@ -389,7 +410,7 @@ class ShieldClient(BaseClient):
         Gets information about Amazon Web Services tags for a specified Amazon Resource
         Name (ARN) in Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_tags_for_resource)
         """
 
@@ -397,7 +418,7 @@ class ShieldClient(BaseClient):
         """
         Adds or updates tags for a resource in Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#tag_resource)
         """
 
@@ -405,10 +426,21 @@ class ShieldClient(BaseClient):
         """
         Removes tags from a resource in Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#untag_resource)
         """
 
+    def update_application_layer_automatic_response(
+        self, *, ResourceArn: str, Action: "ResponseActionTypeDef"
+    ) -> Dict[str, Any]:
+        """
+        Updates an existing Shield Advanced automatic application layer DDoS mitigation
+        configuration for the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.update_application_layer_automatic_response)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_application_layer_automatic_response)
+        """
+
     def update_emergency_contact_settings(
         self, *, EmergencyContactList: Sequence["EmergencyContactTypeDef"] = ...
     ) -> Dict[str, Any]:
@@ -418,7 +450,7 @@ class ShieldClient(BaseClient):
         engagement enabled, for escalations to the SRT and to initiate proactive
         customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.update_emergency_contact_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.update_emergency_contact_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_emergency_contact_settings)
         """
 
@@ -434,7 +466,7 @@ class ShieldClient(BaseClient):
         """
         Updates an existing protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.update_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.update_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_protection_group)
         """
 
@@ -442,14 +474,14 @@ class ShieldClient(BaseClient):
         """
         Updates the details of an existing subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Client.update_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Client.update_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_subscription)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_attacks"]) -> ListAttacksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Paginator.ListAttacks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Paginator.ListAttacks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listattackspaginator)
         """
 
@@ -458,6 +490,6 @@ class ShieldClient(BaseClient):
         self, operation_name: Literal["list_protections"]
     ) -> ListProtectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/shield.html#Shield.Paginator.ListProtections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.18/reference/services/shield.html#Shield.Paginator.ListProtections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listprotectionspaginator)
         """
