@@ -6,9 +6,9 @@ Type annotations for shield service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_shield.literals import AttackLayerType
+    from mypy_boto3_shield.literals import ApplicationLayerAutomaticResponseStatusType
 
-    data: AttackLayerType = "APPLICATION"
+    data: ApplicationLayerAutomaticResponseStatusType = "DISABLED"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "ApplicationLayerAutomaticResponseStatusType",
     "AttackLayerType",
     "AttackPropertyIdentifierType",
     "AutoRenewType",
@@ -37,6 +38,7 @@ __all__ = (
 )
 
 
+ApplicationLayerAutomaticResponseStatusType = Literal["DISABLED", "ENABLED"]
 AttackLayerType = Literal["APPLICATION", "NETWORK"]
 AttackPropertyIdentifierType = Literal[
     "DESTINATION_URL",
@@ -78,6 +80,7 @@ ServiceName = Literal[
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -92,6 +95,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -146,6 +150,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -167,6 +172,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -193,6 +199,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -206,6 +213,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -251,7 +259,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -280,11 +290,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -294,6 +306,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -351,6 +364,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal["list_attacks", "list_protections"]
